@@ -16,7 +16,7 @@ import (
 type APIConnReverseTest struct{}
 
 func (APIConnReverseTest) HasSynced() bool                    { return true }
-func (APIConnReverseTest) Run()                               { return }
+func (APIConnReverseTest) Run()                               {}
 func (APIConnReverseTest) Stop() error                        { return nil }
 func (APIConnReverseTest) PodIndex(string) []*object.Pod      { return nil }
 func (APIConnReverseTest) EpIndex(string) []*object.Endpoints { return nil }
